@@ -1,8 +1,10 @@
-/* $Id: network.c,v 1.7 2001/05/22 23:42:07 kuhlmann Exp $ */
+/* $Id: network.c,v 1.19 2002/09/29 01:39:59 kuhlmann Exp $ */
+/* Copyright: This file may be distributed under version 2 of the GPL licence. */
 
 #include "micq.h"
 #include "util_ui.h"
 #include "network.h"
+#include "preferences.h"
 #include <assert.h>
 
 static UWORD recv_packs[MAX_SEQ_DEPTH];
@@ -22,12 +24,8 @@ BOOL Is_Repeat_Packet (UWORD this_seq)
         }
         if (recv_packs[i] == this_seq)
         {
-            if (Verbose)
-            {
-                R_undraw ();
-                M_print (i18n (623, "\nDoubled packet %04X\n"), this_seq);
-                R_redraw ();
-            }
+            if (prG->verbose & DEB_PROTOCOL)
+                M_printf (i18n (1623, "Doubled packet %04X\n"), this_seq);
             return TRUE;
         }
     }
