@@ -1,15 +1,29 @@
-/* $Id: tabs.c,v 1.3 2001/05/22 23:42:07 kuhlmann Exp $ */
-
 /*
  * Handles a list of recently used UINs that are to be recalled by pressing
  * tab.
  *
- * This file is  Rdiger Kuhlmann; it may be distributed under the lastest
- * version of your choice of the GPL or BSD licence.
+ * mICQ Copyright (C) © 2001,2002,2003 Rüdiger Kuhlmann
+ *
+ * mICQ is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 dated June, 1991.
+ *
+ * mICQ is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+ * License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this package; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ *
+ * $Id: tabs.c,v 1.10.2.1 2003/05/12 14:38:39 kuhlmann Exp $
  */
 
 #include "micq.h"
 #include "tabs.h"
+#include "contact.h"
 
 static UDWORD tab_array[TAB_SLOTS + 1] = { 0 };
 static int tab_pointer = 0;
@@ -20,19 +34,10 @@ static int tab_pointer = 0;
  */
 void TabAddUIN (UDWORD uin)
 {
-    int i, found = 0;
+    int found;
 
-    for (i = 0; i < Num_Contacts; i++)
-    {
-        if (Contacts[i].uin == uin)
-        {
-            found = 1;
-            break;
-        }
-    }
-
-    if (!found)
-        return;
+    if (!ContactFind (NULL, 0, uin, NULL, 0))
+        return ;
 
     for (found = 0; found < TAB_SLOTS; found++)
         if (tab_array[found] == uin)
